{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Hashmap" %}{% endblock %}

{% block main %}
<div class="row-fluid">
  <div class="span12">

{% if service_period %}
  {% blocktrans with service_period as period %}
   <p>Usage data are collected every {{ period }} seconds.</p>
  {% endblocktrans %}
{% endif %}

  {{ tab_group.render }}
  </div>
</div>
{% endblock %}
