{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}

{% block modal-body-right %}
    <h3>{% trans "Description:" %}</h3>
    <p>
      {% blocktrans with module_id=module_id %}
        Edit the priority for the <i>{{ module_id }}</i> module.
      {% endblocktrans %}
    </p>
{% endblock %}
